from setuptools import setup

setup(name='mh_package',
      version='0.13',
      description='My mh_package version',
      url='https://job4moshe@dev.azure.com/job4moshe/mh_package/_git/mh_package',
      author='Moshe Hayoun',
      author_email='job4moshe@gmail.com',
      license='MIT',
      packages=['mh_package'],
      zip_safe=False)
